@@ -75,7 +75,7 @@
 # Make version info available
 __ver_major__ = 1
 __ver_minor__ = 1
-__ver_patch__ = 4
+__ver_patch__ = 5
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,
                               __ver_patch__,__ver_sub__)
@@ -904,7 +904,21 @@ class TestDict(unittest.TestCase):
     def test_suggest(self):
         """Test that suggest() gets simple suggestions right."""
         self.assert_("hello" in self.dict.suggest("helo"))
-    
+
+    def test_suggestHang1(self):
+        """Test whether suggest() hangs on some inputs (Bug #1404196)"""
+        self.assert_(len(self.dict.suggest("Thiis")) >= 0)
+        self.assert_(len(self.dict.suggest("Thiiis")) >= 0)
+        self.assert_(len(self.dict.suggest("Thiiiis")) >= 0)
+
+    def test_unicode1(self):
+        """Test checking/suggesting for unicode strings"""
+        us1 = u"\u21496"
+        self.assert_(type(us1) == unicode)
+        self.failIf(self.dict.check(us1))
+        for s in self.dict.suggest(us1):
+            self.assert_(type(s) == unicode)
+            
     def test_session(self):
         """Test that adding words to the session works as required."""
         self.failIf(self.dict.check("Lozz"))
